@@ -1,4 +1,5 @@
 use crate::conn::Conn;
+use serde_json::{json, Value};
 use std::{collections::HashMap, future::Future, pin::Pin};
 use uuid::Uuid;
 
@@ -8,8 +9,8 @@ pub fn get_language(c: Conn) -> Pin<Box<dyn Future<Output = Conn>>> {
     Box::pin(get_language_conn(c))
 }
 
-pub fn fetch_session(c: Conn) -> Pin<Box<dyn Future<Output = Conn>>> {
-    Box::pin(fetch_session_conn(c))
+pub fn get_session_id(c: Conn) -> Pin<Box<dyn Future<Output = Conn>>> {
+    Box::pin(get_session_id_conn(c))
 }
 
 pub async fn get_language_conn(conn: Conn) -> Conn {
@@ -18,22 +19,22 @@ pub async fn get_language_conn(conn: Conn) -> Conn {
         None => DEFAULT_LANGUAGE,
     };
 
-    let mut assigns: HashMap<String, String> = conn.assigns.clone();
-    assigns.insert("language".to_owned(), lang.to_owned());
+    let mut assigns: HashMap<String, Value> = conn.assigns.clone();
+    assigns.insert("language".to_owned(), json!(lang.to_owned()));
     return Conn {
         assigns: assigns,
         ..conn
     };
 }
 
-pub async fn fetch_session_conn(conn: Conn) -> Conn {
+pub async fn get_session_id_conn(conn: Conn) -> Conn {
     match conn.req_headers.get("cookie") {
         Some(cookies) => {
             for c in cookies.split(";") {
                 let v: Vec<&str> = c.split("=").collect();
                 if v[0] == "confetti_session_id" {
-                    let mut assigns: HashMap<String, String> = conn.assigns.clone();
-                    assigns.insert("session_id".to_owned(), v[1].to_owned());
+                    let mut assigns: HashMap<String, Value> = conn.assigns.clone();
+                    assigns.insert("session_id".to_owned(), json!(v[1].to_owned()));
                     return Conn {
                         assigns: assigns,
                         ..conn
@@ -55,8 +56,8 @@ fn generate_session_id() -> String {
 
 fn add_new_session(conn: Conn) -> Conn {
     let session_id = generate_session_id();
-    let mut assigns: HashMap<String, String> = conn.assigns.clone();
-    assigns.insert("session_id".to_owned(), session_id.clone());
+    let mut assigns: HashMap<String, Value> = conn.assigns.clone();
+    assigns.insert("session_id".to_owned(), json!(session_id.clone()));
 
     let mut resp_headers: HashMap<String, String> = conn.resp_headers.clone();
     resp_headers.insert(
